@@ -293,7 +293,7 @@ errorsarlm <- function(formula, data = list(), listw, na.action, weights=NULL,
                     rownames(indirImps) <- rownames(cm)
                 }
             }
-            totImps <- as.matrix(estimable(lm.target, cm)[, 1:2, drop=FALSE])
+            totImps <- as.matrix(.estimable(lm.target, cm)[, 1:2, drop=FALSE])
           } else if (is.formula(Durbin)) {
 #FIXME
               m <- sum(dvars)
@@ -322,7 +322,7 @@ errorsarlm <- function(formula, data = list(), listw, na.action, weights=NULL,
                 }
               }
               rownames(indirImps) <- xn
-              totImps <- as.matrix(estimable(lm.target, cm)[, 1:2,
+              totImps <- as.matrix(.estimable(lm.target, cm)[, 1:2,
                 drop=FALSE])
               if (!is.null(zero_fill)) {
                 if (length(zero_fill) > 0L) {
